//
// BonusCalculator.js
//
// Provides a UI to select modifiers from a list and then print out the final modifier (penalty or bonus)
// to the chat box.
// 
// You can add new items by updating the lists in recalcBonus() function and ensuring that the radio/select/drop down
// are defined in the HTML with the proper name/id.
//

main();

async function main()
{

    let form = getForm();


  let diceDialog = new Dialog({
    title: 'Select Modifier Categories:',
    content: form,
    buttons: {
      no: {
        icon: '<i class="fas fa-times"></i>',
        label: 'Cancel'
      },
      yes: {
        icon: '<i class="fas fa-check"></i>',
        label: 'Calculate',
        callback: async (html) => {

            //console.log("--" + html);
            //let test = html.getElementsByName("wound");

            value = recalcBonus(html);
            //console.log("The Value:" + value);
  
            let chatString = "Modifier: " + value;
            //html.find('[name="baseinput"]').val();

            ChatMessage.create({ content: chatString });

        }
      },
    },
    default: 'yes',
    close: () => {
      console.log('Example Dialog Closed');
    }
  }).render(true);
}

// Defines the form to use in the Dialog.
// NOTE: using a template would be better but I wanted everything in one file.
function getForm()
{
    return `
    
    <form id="mainform">
    <table>
    <tr>
    <td>
      <label for="range">Range: </label>
      </td>
      <td>
      <select name="range" id="range">
      <option value="0">Short</option>
      <option value="-2">Medium</option>
      <option value="-4">Long</option>
      <option value="-8">Extreme</option>  
      </select>
      </td>
    <td>
    <label for="wound">Wound: </label>
</td>
<td>
      <select name="wound" id="wound">
      <option value="0"> No Wounds</option>
      <option value="-1">1 Wound</option>
      <option value="-2">2 Wounds</option>
      <option value="-3">3 Wounds</option>
      
      </select>
</td>
</tr>
        <tr>
        <td>
        <label for="fatigue">Fatigue: </label>
        </td>
        <td>
        <select name="fatigue" id="fatigue">
        <option value="0"> None</option>
        <option value="-1">1 fatigue</option>
        <option value="-2">2 fatigue</option>
        </select>
        </td>
<td>
        <label for="cover">Cover: </label>
</td><td>
        <select name="cover" id="cover">
        <option value="0"> None</option>
        <option value="-2">Light</option>
        <option value="-4">Medium</option>
        <option value="-6">Heavy</option>
        <option value="-78">Near Total</option>
        </select>
</td>
</tr>
<tr>
<td>
        <label for="illumination">Illumination: </label>
</td>
<td>
        <select name="illumination" id="illumination">
        <option value="0">Full</option>
        <option value="-2">Dim</option>
        <option value="-4">Dark</option>
        <option value="-6">Pitch Black</option>
        </select>
</td><td>
        <label for="vulnerable">Target Vulnerable: </label>
</td><td>
        <input id="vulnerable" type="checkbox" name="vulnerable" value="+2">
</td></tr>
<tr>
<td>
        <label for="distracted">Attacker Distracted: </label>
</td><td>
        <input id="distracted" type="checkbox" name="distracted" value="-2">
</td><td>
        <label for="unstable">Unstable Platform: </label>
</td><td>
        <input id="unstable" type="checkbox" name="unstable" value="-2">
<td></tr>
<tr>
<td>
        <label for="wild">Wild Attack: </label>
</td><td>
        <input id="wild" type="checkbox" name="wild" value="+2">
</td><td>
        <label for="burst">3 Round Burst: </label>
 </td><td>
        <input id="burst" type="checkbox" name="burst" value="+1">
</td></tr>
<tr>
<td>
        <label for="aim">Aiming: </label>
</td><td>

        <input id="aim" type="checkbox" name="aim" value="+2">
</td><td>
        <label for="offhand">Off Handed: </label>
</td><td>
        <input id="offhand" type="checkbox" name="offhand" value="-2">
</td></tr>
<tr>
<td>
        <label for="multishot">Recoil: </label>
</td><td>
        <input id="multishot" type="checkbox" name="multishot" value="-2">
</td><td>    
        <label for="twoone">2 Weapon vs. 1: </label>
</td><td>
        <input id="twoone" type="checkbox" name="twoone" value="+1">
</td></tr>
<tr>
<td>
        <label for="touch">Touch Attack: </label>
</td><td>
        <input id="touch" type="checkbox" name="touch" value="+2">
</td></tr></table>
     </div>
    </form>

    
    `;
}

function recalcBonus(html)
{

   // console.log("----" + html);
            

  // All the check boxes.
  var checkboxBonusList = ['vulnerable', 'unstable', 'aim', 'distracted', 'burst', 'multishot', 'offhand', 'wild', 'twoone', 'touch'];
  // All the radio buttons.
  var radioBonusList = [];
  // All the drop down items.
  var selectBonusList = ['range', "wound", "fatigue", "cover", "illumination"];

  // Overall value
  var value = 0;

  // Loop through the checkboxes
  for (i=0; i<checkboxBonusList.length; i++)
  {
    value += getCheckboxValue(checkboxBonusList[i], html);
  }
  // Loop through the radio buttons
  for (i=0; i<radioBonusList.length; i++)
  {
    value += getRadioValue(radioBonusList[i], html);
  }

  // loop through all the drop downs
  for (i=0; i<selectBonusList.length; i++) 
  {
    value += getSelectValue(selectBonusList[i], html);
  }
  console.log("out of recalc function");
  
  return value;
//  displayBonus(value);


}

// Function to get the value from a checkbox
function getCheckboxValue(elementName, html)
{

    console.log("------" + html);
            
  var checkedValue = 0;
  var inputElements = html.find('[name="'+ elementName +'"]');
  //var inputElements = html.getElementsByName(elementName);
  for(var i=0; inputElements[i]; ++i){
        if(inputElements[i].checked){
             checkedValue = checkedValue + parseInt(inputElements[i].value);
             break;
        }
  }

  //console.log("Element:"+ elementName + " checkValue:" + checkedValue);

  return(checkedValue);
}

function getSelectValue(elementName, html)
{
    var radioValue = 0;

    //var radios = html.getElementsByName(elementName);
    var radios = html.find('[name="'+ elementName +'"]');
    for (var i = 0, length = radios.length; i < length; i++)
    {
      
          // do whatever you want with the checked radio
          radioValue = parseInt(radios[i].value);

          // only one radio can be logically checked, don't check the rest
          break;

    }
    //console.log("Element: " + elementName + " radioValue:" + radioValue);

    return(radioValue);
}

// Function to get the value of a set of radio buttons
function getRadioValue(elementName, html)
{
    var radioValue = 0;

    var radios = html.find('[name="'+ elementName +'"]');
 
    //var radios = html.getElementsByName(elementName);
    for (var i = 0, length = radios.length; i < length; i++)
    {
      if (radios[i].checked)
      {
          // do whatever you want with the checked radio
          radioValue = parseInt(radios[i].value);

          // only one radio can be logically checked, don't check the rest
          break;
      }
    }
    //console.log("Element: " + elementName + " radioValue:" + radioValue);

    return(radioValue);
}
